==> gesundheit-0.1.2.tgz: package/lib/sud-query.js <==
(function() {
  var Query, SUDQuery, Select, fluid, normalize, unknown;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __slice = Array.prototype.slice;
  fluid = require('./fluid');
  Query = require('./base-query');
  Select = require('./select');
  normalize = require('./normalize');
  exports.SUDQuery = SUDQuery = (function() {
    __extends(SUDQuery, Query);
    function SUDQuery(table, opts) {
      var alias, _ref;
      SUDQuery.__super__.constructor.call(this, opts);
      this.s.includedAliases = {};
      this.s.tableStack = [];
      this.s.where = [];
      this.s.order = [];
      this.s.parameters = [];
      if (table != null) {
        _ref = this.aliasPair(table), table = _ref[0], alias = _ref[1];
        this.pushTable(table, alias);
      }
    }
    SUDQuery.prototype.join = fluid(function(tbl, opts) {
      var alias, clause, table, type, _ref;
      if (opts == null) {
        opts = {};
      }
      _ref = this.aliasPair(tbl), table = _ref[0], alias = _ref[1];
      if (this.includesAlias(alias)) {
        throw new Error("Table alias is not unique: " + alias);
      }
      type = this.dialect.joinType(opts.type);
      if ((clause = opts.on) != null) {
        if (clause.constructor !== Array) {
          clause = [clause];
        }
        clause = normalize.clauses(clause, alias, this.dialect.joinOp);
        if (clause.length > 1) {
          clause = {
            op: 'multi',
            glue: ' AND ',
            clauses: clause
          };
        } else {
          clause = clause[0];
        }
      }
      this.pushTable(table, alias, type, clause);
      if (opts.fields != null) {
        return this.fields.apply(this, opts.fields);
      }
    });
    SUDQuery.prototype.from = fluid(function(alias) {
      var table;
      if (table = this.includesAlias(alias)) {
        return this.pushTable(table, alias, 'NOP');
      } else {
        return unknown('table', table);
      }
    });
    SUDQuery.prototype.where = fluid(function(alias, clause) {
      var normalized, table, _ref, _ref2;
      if (!(clause != null)) {
        clause = alias;
        alias = this.lastAlias();
      } else {
        _ref = this.aliasPair(alias), table = _ref[0], alias = _ref[1];
      }
      if (this.includesAlias(alias) == null) {
        unknown('table', tbl);
      }
      normalized = normalize.clauses([clause], alias, this.dialect.whereOp);
      (_ref2 = this.s.where).push.apply(_ref2, normalized);
      return this.pushParams(normalized);
    });
    SUDQuery.prototype.or = fluid(function() {
      var args, clauses;
      args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      clauses = normalize.clauses(args, this.lastAlias(), this.dialect.whereOp);
      this.s.where.push({
        op: 'multi',
        glue: ' OR ',
        clauses: clauses
      });
      return this.pushParams(clauses);
    });
    SUDQuery.prototype.orderBy = fluid(function() {
      var args, orderings, _ref;
      args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      orderings = normalize.orderings(args, this.lastAlias(), this.dialect.order);
      return (_ref = this.s.order).push.apply(_ref, orderings);
    });
    SUDQuery.prototype.limit = fluid(function(l) {
      return this.s.limit = l;
    });
    SUDQuery.prototype.aliasPair = function(table) {
      var a, t;
      if ('object' === typeof table && Object.keys(table).length === 1) {
        return ((function() {
          var _results;
          _results = [];
          for (a in table) {
            t = table[a];
            _results.push([this.resolve.table(t), a]);
          }
          return _results;
        }).call(this))[0];
      } else {
        t = this.resolve.table(table);
        return [t, t];
      }
    };
    SUDQuery.prototype.pushTable = function(table, alias, type, clause) {
      if (table === "t1t1") {
        throw new Error("here");
      }
      if (type !== 'NOP') {
        this.s.includedAliases[alias] = table;
      }
      return this.s.tableStack.push([table, alias, type, clause]);
    };
    SUDQuery.prototype.pushParams = function(clauses) {
      var clause, _i, _len, _ref, _results;
      _results = [];
      for (_i = 0, _len = clauses.length; _i < _len; _i++) {
        clause = clauses[_i];
        _results.push(clause.op === 'multi' ? (sys.puts("pushParam recursing" + clause.clauses), this.pushParams(clause.clauses)) : clause.op === 'IN' ? (_ref = this.s.parameters).push.apply(_ref, clause.value) : this.s.parameters.push(clause.value));
      }
      return _results;
    };
    SUDQuery.prototype.lastAlias = function() {
      return this.s.tableStack[this.s.tableStack.length - 1][1];
    };
    SUDQuery.prototype.includesAlias = function(a) {
      return this.s.includedAliases[a];
    };
    return SUDQuery;
  })();
  unknown = function(type, val) {
    throw new Error("Unknown " + type + ": " + val);
  };
}).call(this);

==> gesundheit-0.1.3.tgz: package/lib/sud-query.js <==
(function() {
  var DEFAULT, NOT_NULL, NULL, Query, SUDQuery, Select, fluid, normalize, unknown, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __slice = Array.prototype.slice;
  fluid = require('./fluid');
  Query = require('./base-query');
  Select = require('./select');
  normalize = require('./normalize');
  _ref = require('./dialects/common'), NULL = _ref.NULL, NOT_NULL = _ref.NOT_NULL, DEFAULT = _ref.DEFAULT;
  exports.SUDQuery = SUDQuery = (function() {
    __extends(SUDQuery, Query);
    function SUDQuery(table, opts) {
      var alias, _ref2;
      SUDQuery.__super__.constructor.call(this, opts);
      this.s.includedAliases = {};
      this.s.tableStack = [];
      this.s.where = [];
      this.s.order = [];
      this.s.parameters = [];
      if (table != null) {
        _ref2 = this.aliasPair(table), table = _ref2[0], alias = _ref2[1];
        this.pushTable(table, alias);
      }
    }
    SUDQuery.prototype.join = fluid(function(tbl, opts) {
      var alias, clause, table, type, _ref2;
      if (opts == null) {
        opts = {};
      }
      _ref2 = this.aliasPair(tbl), table = _ref2[0], alias = _ref2[1];
      if (this.includesAlias(alias)) {
        throw new Error("Table alias is not unique: " + alias);
      }
      type = this.dialect.joinType(opts.type);
      if ((clause = opts.on) != null) {
        if (clause.constructor !== Array) {
          clause = [clause];
        }
        clause = normalize.clauses(clause, alias, this.dialect.joinOp);
        if (clause.length > 1) {
          clause = {
            op: 'multi',
            glue: ' AND ',
            clauses: clause
          };
        } else {
          clause = clause[0];
        }
      }
      this.pushTable(table, alias, type, clause);
      if (opts.fields != null) {
        return this.fields.apply(this, opts.fields);
      }
    });
    SUDQuery.prototype.from = fluid(function(alias) {
      var table;
      if (table = this.includesAlias(alias)) {
        return this.pushTable(table, alias, 'NOP');
      } else {
        return unknown('table', table);
      }
    });
    SUDQuery.prototype.where = fluid(function(alias, clause) {
      var normalized, table, _ref2, _ref3;
      if (!(clause != null)) {
        clause = alias;
        alias = this.lastAlias();
      } else {
        _ref2 = this.aliasPair(alias), table = _ref2[0], alias = _ref2[1];
      }
      if (this.includesAlias(alias) == null) {
        unknown('table', tbl);
      }
      normalized = normalize.clauses([clause], alias, this.dialect.whereOp);
      (_ref3 = this.s.where).push.apply(_ref3, normalized);
      return this.pushParams(normalized);
    });
    SUDQuery.prototype.or = fluid(function() {
      var args, clauses;
      args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      clauses = normalize.clauses(args, this.lastAlias(), this.dialect.whereOp);
      this.s.where.push({
        op: 'multi',
        glue: ' OR ',
        clauses: clauses
      });
      return this.pushParams(clauses);
    });
    SUDQuery.prototype.orderBy = fluid(function() {
      var args, orderings, _ref2;
      args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      orderings = normalize.orderings(args, this.lastAlias(), this.dialect.order);
      return (_ref2 = this.s.order).push.apply(_ref2, orderings);
    });
    SUDQuery.prototype.limit = fluid(function(l) {
      return this.s.limit = l;
    });
    SUDQuery.prototype.aliasPair = function(table) {
      var a, t;
      if ('object' === typeof table && Object.keys(table).length === 1) {
        return ((function() {
          var _results;
          _results = [];
          for (a in table) {
            t = table[a];
            _results.push([this.resolve.table(t), a]);
          }
          return _results;
        }).call(this))[0];
      } else {
        t = this.resolve.table(table);
        return [t, t];
      }
    };
    SUDQuery.prototype.pushTable = function(table, alias, type, clause) {
      if (table === "t1t1") {
        throw new Error("here");
      }
      if (type !== 'NOP') {
        this.s.includedAliases[alias] = table;
      }
      return this.s.tableStack.push([table, alias, type, clause]);
    };
    SUDQuery.prototype.pushParams = function(clauses) {
      var clause, _i, _len, _ref2, _ref3, _results;
      _results = [];
      for (_i = 0, _len = clauses.length; _i < _len; _i++) {
        clause = clauses[_i];
        _results.push(clause.op === 'multi' ? this.pushParams(clause.clauses) : clause.op === 'IN' ? (_ref2 = this.s.parameters).push.apply(_ref2, clause.value) : (_ref3 = clause.value) !== NULL && _ref3 !== NOT_NULL && _ref3 !== DEFAULT ? this.s.parameters.push(clause.value) : void 0);
      }
      return _results;
    };
    SUDQuery.prototype.lastAlias = function() {
      return this.s.tableStack[this.s.tableStack.length - 1][1];
    };
    SUDQuery.prototype.includesAlias = function(a) {
      return this.s.includedAliases[a];
    };
    return SUDQuery;
  })();
  unknown = function(type, val) {
    throw new Error("Unknown " + type + ": " + val);
  };
}).call(this);
